These images were captured with my OAK-D Lite camera with the medium resolution setting (640x480).

Rectification was done on device with the factory values.

Note that there is a slightly annoying border in the left images that comes from the rectification. The disparity in that area should be ignored.
